pushoverr is package for sending push notifications to mobile devices
(iOS and Android) and the desktop using
Pushover. Messages can be quickly sent using the
pushover function. Apple Watch users can push small bits of
data to their watches using update_glance.
This package and its author are not affiliated with Superblock, LLC, creators of Pushover.
To use pushoverr, you will first need your user key and an
application token. The user key can be found within the settings of
the app (e.g., uQiRzpo4DXghDmr9QzzfQu27cmVRsG) or by logging in to
https://pushover.net. To receive an application token, register a new
application after logging in to https://pushover.net/apps.
For more information, browse the package index by following the link
at the bottom of this help page. For release information, run
news(package = "pushoverr").
GitHub Repository: https://github.com/briandconnelly/pushoverr
Bug Reports and Feature Requests: https://github.com/briandconnelly/pushoverr/issues
Pushover: https://pushover.net
Pushover API: https://pushover.net/api